window.Gleam.initSearch([{"doc":"html_components","title":"html_components","content":"# HTML components for gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/html_components)](https://hex.pm/packages/html_components)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/html_components/)\n[![Tests](https://github.com/andre-dasilva/html_components/actions/workflows/test.yml/badge.svg)](https://github.com/andre-dasilva/html_components/actions/workflows/test.yml)\n\nGenerate HTML (or XML) from simple gleam functions\n\nFurther documentation can be found at &lt;https://hexdocs.pm/html_components&gt;.\n\n## Getting Started\n\n### Installation\n\n```sh\ngleam add html_components\n```\n\n### Usage\n\n#### HTML\n\n```gleam\nimport html_components/elements\nimport html_components/html\nimport html_components/render\n\nlet input =\n  html.html([elements.attr(&quot;lang&quot;, &quot;en&quot;)], [\n    html.head([], [html.title(&quot;Nested&quot;)]),\n    html.body([], [\n      html.h1([], [elements.text(&quot;Hello&quot;)]),\n      html.div([elements.attr(&quot;class&quot;, &quot;text-2xl&quot;)], [\n        html.p([], [elements.text(&quot;What a nice library&quot;)]),\n      ]),\n    ]),\n  ])\n\nrender.html(input)\n// &lt;!DOCTYPE html&gt;&lt;html lang=&quot;en&quot;&gt;&lt;head&gt;&lt;title&gt;Nested&lt;/title&gt;&lt;/head&gt;&lt;body&gt;&lt;h1&gt;Hello&lt;/h1&gt;&lt;div class=&quot;text-2xl&quot;&gt;&lt;p&gt;What a nice library&lt;/p&gt;&lt;/div&gt;&lt;/body&gt;&lt;/html&gt;\n```\n\n#### XML\nSince the functions are quite generic, its also possible to generate xml\n\n```gleam\nimport html_components/elements\nimport html_components/render\n\nlet book_element = fn(id: String, author: String, title: String) {\n  elements.element(&quot;book&quot;, [elements.attr(&quot;id&quot;, id)], [\n    elements.element(&quot;author&quot;, [], [elements.text(author)]),\n    elements.element(&quot;title&quot;, [], [elements.text(title)]),\n  ])\n}\n\nlet books_element = fn(books) { elements.element(&quot;books&quot;, [], books) }\n\nlet input =\n  books_element([\n    book_element(&quot;1&quot;, &quot;J. K. Rowling&quot;, &quot;Philosopher&#39;s Stone&quot;),\n    book_element(&quot;2&quot;, &quot;Douglas Adams&quot;, &quot;The Hitchhiker&#39;s Guide to the Galaxy&quot;)\n  ])\n\nrender.xml(input)\n// &lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt;&lt;books&gt;&lt;book id=&quot;1&quot;&gt;&lt;author&gt;J. K. Rowling&lt;/author&gt;&lt;title&gt;Philosopher&amp;#x27;s Stone&lt;/title&gt;&lt;/book&gt;&lt;book id=&quot;2&quot;&gt;&lt;author&gt;Douglas Adams&lt;/author&gt;&lt;title&gt;The Hitchhiker&amp;#x27;s Guide to the Galaxy&lt;/title&gt;&lt;/book&gt;&lt;/books&gt;\n```\n\n## Development\n\nFork the project and clone it\n\nYou can run the tests with:\n\n```sh\ngleam test\n```\n","url":"index.html"},{"doc":"elements","title":"Attribute","content":"pub type Attribute {\n  Attribute(key: String, value: String)\n}\n\nAttribute(key: String, value: String)\n\n\nSynonyms:\nelements.Attribute\nelements Attribute","url":"elements.html#Attribute"},{"doc":"elements","title":"Element","content":"pub type Element {\n  Element(\n    tag: String,\n    attrs: List(Attribute),\n    children: List(Element),\n  )\n  EscapeText(String)\n  Text(String)\n  CData(String)\n}\n\nElement(\n  tag: String,\n  attrs: List(Attribute),\n  children: List(Element),\n)\n\n\nEscapeText(String)\n\n\nText(String)\n\n\nCData(String)\n\n\nSynonyms:\nelements.Element\nelements Element","url":"elements.html#Element"},{"doc":"elements","title":"attr","content":"pub fn attr(key: String, value: String) -&gt; Attribute\n\nSynonyms:\nelements.attr\nelements attr","url":"elements.html#attr"},{"doc":"elements","title":"cdata","content":"pub fn cdata(value: String) -&gt; Element\n\nSynonyms:\nelements.cdata\nelements cdata","url":"elements.html#cdata"},{"doc":"elements","title":"element","content":"pub fn element(\n  tag: String,\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nelements.element\nelements element","url":"elements.html#element"},{"doc":"elements","title":"element_self_closing","content":"pub fn element_self_closing(\n  tag: String,\n  attrs: List(Attribute),\n) -&gt; Element\n\nSynonyms:\nelements.element_self_closing\nelements element_self_closing","url":"elements.html#element_self_closing"},{"doc":"elements","title":"escape_text","content":"pub fn escape_text(value: String) -&gt; Element\n\nSynonyms:\nelements.escape_text\nelements escape_text","url":"elements.html#escape_text"},{"doc":"elements","title":"text","content":"pub fn text(value: String) -&gt; Element\n\nSynonyms:\nelements.text\nelements text","url":"elements.html#text"},{"doc":"elements","title":"elements","content":"","url":"elements.html"},{"doc":"html","title":"a","content":"pub fn a(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.a\nhtml a","url":"html.html#a"},{"doc":"html","title":"address","content":"pub fn address(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.address\nhtml address","url":"html.html#address"},{"doc":"html","title":"area","content":"pub fn area(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.area\nhtml area","url":"html.html#area"},{"doc":"html","title":"article","content":"pub fn article(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.article\nhtml article","url":"html.html#article"},{"doc":"html","title":"aside","content":"pub fn aside(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.aside\nhtml aside","url":"html.html#aside"},{"doc":"html","title":"audio","content":"pub fn audio(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.audio\nhtml audio","url":"html.html#audio"},{"doc":"html","title":"b","content":"pub fn b(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.b\nhtml b","url":"html.html#b"},{"doc":"html","title":"bdo","content":"pub fn bdo(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.bdo\nhtml bdo","url":"html.html#bdo"},{"doc":"html","title":"blockquote","content":"pub fn blockquote(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.blockquote\nhtml blockquote","url":"html.html#blockquote"},{"doc":"html","title":"body","content":"pub fn body(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.body\nhtml body","url":"html.html#body"},{"doc":"html","title":"br","content":"pub fn br(attrs: List(Attribute)) -&gt; Element\n\nSynonyms:\nhtml.br\nhtml br","url":"html.html#br"},{"doc":"html","title":"cite","content":"pub fn cite(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.cite\nhtml cite","url":"html.html#cite"},{"doc":"html","title":"code","content":"pub fn code(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.code\nhtml code","url":"html.html#code"},{"doc":"html","title":"col","content":"pub fn col(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.col\nhtml col","url":"html.html#col"},{"doc":"html","title":"colgroup","content":"pub fn colgroup(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.colgroup\nhtml colgroup","url":"html.html#colgroup"},{"doc":"html","title":"datalist","content":"pub fn datalist(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.datalist\nhtml datalist","url":"html.html#datalist"},{"doc":"html","title":"del","content":"pub fn del(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.del\nhtml del","url":"html.html#del"},{"doc":"html","title":"details","content":"pub fn details(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.details\nhtml details","url":"html.html#details"},{"doc":"html","title":"dialog","content":"pub fn dialog(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.dialog\nhtml dialog","url":"html.html#dialog"},{"doc":"html","title":"div","content":"pub fn div(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.div\nhtml div","url":"html.html#div"},{"doc":"html","title":"document","content":"pub fn document(\n  attrs: List(Attribute),\n  head_elements: List(Element),\n  body_elements: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.document\nhtml document","url":"html.html#document"},{"doc":"html","title":"fieldset","content":"pub fn fieldset(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.fieldset\nhtml fieldset","url":"html.html#fieldset"},{"doc":"html","title":"figcaption","content":"pub fn figcaption(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.figcaption\nhtml figcaption","url":"html.html#figcaption"},{"doc":"html","title":"figure","content":"pub fn figure(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.figure\nhtml figure","url":"html.html#figure"},{"doc":"html","title":"form","content":"pub fn form(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.form\nhtml form","url":"html.html#form"},{"doc":"html","title":"h1","content":"pub fn h1(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.h1\nhtml h1","url":"html.html#h1"},{"doc":"html","title":"h2","content":"pub fn h2(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.h2\nhtml h2","url":"html.html#h2"},{"doc":"html","title":"h3","content":"pub fn h3(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.h3\nhtml h3","url":"html.html#h3"},{"doc":"html","title":"h4","content":"pub fn h4(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.h4\nhtml h4","url":"html.html#h4"},{"doc":"html","title":"h5","content":"pub fn h5(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.h5\nhtml h5","url":"html.html#h5"},{"doc":"html","title":"h6","content":"pub fn h6(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.h6\nhtml h6","url":"html.html#h6"},{"doc":"html","title":"head","content":"pub fn head(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.head\nhtml head","url":"html.html#head"},{"doc":"html","title":"header","content":"pub fn header(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.header\nhtml header","url":"html.html#header"},{"doc":"html","title":"hr","content":"pub fn hr(attrs: List(Attribute)) -&gt; Element\n\nSynonyms:\nhtml.hr\nhtml hr","url":"html.html#hr"},{"doc":"html","title":"html","content":"pub fn html(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.html\nhtml html","url":"html.html#html"},{"doc":"html","title":"i","content":"pub fn i(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.i\nhtml i","url":"html.html#i"},{"doc":"html","title":"iframe","content":"pub fn iframe(attrs: List(Attribute)) -&gt; Element\n\nSynonyms:\nhtml.iframe\nhtml iframe","url":"html.html#iframe"},{"doc":"html","title":"img","content":"pub fn img(attrs: List(Attribute)) -&gt; Element\n\nSynonyms:\nhtml.img\nhtml img","url":"html.html#img"},{"doc":"html","title":"input","content":"pub fn input(attrs: List(Attribute)) -&gt; Element\n\nSynonyms:\nhtml.input\nhtml input","url":"html.html#input"},{"doc":"html","title":"legend","content":"pub fn legend(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.legend\nhtml legend","url":"html.html#legend"},{"doc":"html","title":"li","content":"pub fn li(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.li\nhtml li","url":"html.html#li"},{"doc":"html","title":"link","content":"pub fn link(attrs: List(Attribute)) -&gt; Element\n\nSynonyms:\nhtml.link\nhtml link","url":"html.html#link"},{"doc":"html","title":"main","content":"pub fn main(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.main\nhtml main","url":"html.html#main"},{"doc":"html","title":"map","content":"pub fn map(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.map\nhtml map","url":"html.html#map"},{"doc":"html","title":"mark","content":"pub fn mark(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.mark\nhtml mark","url":"html.html#mark"},{"doc":"html","title":"meta","content":"pub fn meta(attrs: List(Attribute)) -&gt; Element\n\nSynonyms:\nhtml.meta\nhtml meta","url":"html.html#meta"},{"doc":"html","title":"metre","content":"pub fn metre(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.metre\nhtml metre","url":"html.html#metre"},{"doc":"html","title":"nav","content":"pub fn nav(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.nav\nhtml nav","url":"html.html#nav"},{"doc":"html","title":"noscript","content":"pub fn noscript(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.noscript\nhtml noscript","url":"html.html#noscript"},{"doc":"html","title":"object","content":"pub fn object(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.object\nhtml object","url":"html.html#object"},{"doc":"html","title":"ol","content":"pub fn ol(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.ol\nhtml ol","url":"html.html#ol"},{"doc":"html","title":"optgroup","content":"pub fn optgroup(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.optgroup\nhtml optgroup","url":"html.html#optgroup"},{"doc":"html","title":"output","content":"pub fn output(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.output\nhtml output","url":"html.html#output"},{"doc":"html","title":"p","content":"pub fn p(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.p\nhtml p","url":"html.html#p"},{"doc":"html","title":"pre","content":"pub fn pre(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.pre\nhtml pre","url":"html.html#pre"},{"doc":"html","title":"progress","content":"pub fn progress(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.progress\nhtml progress","url":"html.html#progress"},{"doc":"html","title":"q","content":"pub fn q(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.q\nhtml q","url":"html.html#q"},{"doc":"html","title":"s","content":"pub fn s(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.s\nhtml s","url":"html.html#s"},{"doc":"html","title":"script","content":"pub fn script(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.script\nhtml script","url":"html.html#script"},{"doc":"html","title":"section","content":"pub fn section(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.section\nhtml section","url":"html.html#section"},{"doc":"html","title":"select","content":"pub fn select(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.select\nhtml select","url":"html.html#select"},{"doc":"html","title":"small","content":"pub fn small(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.small\nhtml small","url":"html.html#small"},{"doc":"html","title":"source","content":"pub fn source(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.source\nhtml source","url":"html.html#source"},{"doc":"html","title":"span","content":"pub fn span(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.span\nhtml span","url":"html.html#span"},{"doc":"html","title":"style","content":"pub fn style(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.style\nhtml style","url":"html.html#style"},{"doc":"html","title":"sub","content":"pub fn sub(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.sub\nhtml sub","url":"html.html#sub"},{"doc":"html","title":"summary","content":"pub fn summary(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.summary\nhtml summary","url":"html.html#summary"},{"doc":"html","title":"sup","content":"pub fn sup(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.sup\nhtml sup","url":"html.html#sup"},{"doc":"html","title":"table","content":"pub fn table(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.table\nhtml table","url":"html.html#table"},{"doc":"html","title":"td","content":"pub fn td(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.td\nhtml td","url":"html.html#td"},{"doc":"html","title":"template","content":"pub fn template(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.template\nhtml template","url":"html.html#template"},{"doc":"html","title":"textarea","content":"pub fn textarea(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.textarea\nhtml textarea","url":"html.html#textarea"},{"doc":"html","title":"th","content":"pub fn th(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.th\nhtml th","url":"html.html#th"},{"doc":"html","title":"time","content":"pub fn time(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.time\nhtml time","url":"html.html#time"},{"doc":"html","title":"title","content":"pub fn title(title: String) -&gt; Element\n\nSynonyms:\nhtml.title\nhtml title","url":"html.html#title"},{"doc":"html","title":"tr","content":"pub fn tr(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.tr\nhtml tr","url":"html.html#tr"},{"doc":"html","title":"track","content":"pub fn track(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.track\nhtml track","url":"html.html#track"},{"doc":"html","title":"u","content":"pub fn u(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.u\nhtml u","url":"html.html#u"},{"doc":"html","title":"ul","content":"pub fn ul(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.ul\nhtml ul","url":"html.html#ul"},{"doc":"html","title":"var","content":"pub fn var(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.var\nhtml var","url":"html.html#var"},{"doc":"html","title":"video","content":"pub fn video(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nhtml.video\nhtml video","url":"html.html#video"},{"doc":"html","title":"html","content":"","url":"html.html"},{"doc":"render","title":"element","content":"pub fn element(el: Element) -&gt; String\n\nSynonyms:\nrender.element\nrender element","url":"render.html#element"},{"doc":"render","title":"escape","content":"pub fn escape(value: String) -&gt; String\n\nSynonyms:\nrender.escape\nrender escape","url":"render.html#escape"},{"doc":"render","title":"html","content":"pub fn html(el: Element) -&gt; String\n\nSynonyms:\nrender.html\nrender html","url":"render.html#html"},{"doc":"render","title":"xml","content":"pub fn xml(el: Element) -&gt; String\n\nSynonyms:\nrender.xml\nrender xml","url":"render.html#xml"},{"doc":"render","title":"render","content":"","url":"render.html"},{"doc":"xml","title":"Sitemap","content":"pub type Sitemap {\n  SitemapUrl(loc: String, lastmod: String)\n}\n\nSitemapUrl(loc: String, lastmod: String)\n\n\nSynonyms:\nxml.Sitemap\nxml Sitemap","url":"xml.html#Sitemap"},{"doc":"xml","title":"sitemap","content":"pub fn sitemap(items: List(Sitemap)) -&gt; Element\n\nSynonyms:\nxml.sitemap\nxml sitemap","url":"xml.html#sitemap"},{"doc":"xml","title":"xml","content":"","url":"xml.html"}]);